@@ -1,6 +1,6 @@
 #------ these parameters need to be changed depending on lcuster
 outdir = "./scratch/"
-pseudo_dir = "/home/MatSim/harishpvv/aldtest/Si/"
+pseudo_dir = "./"
 home_bashrc = "~/.bashrc"
 submission_command = "bash"  # could be qsub, mysub, sbatch, etc
 
