@@ -16,7 +16,7 @@ OMP_NUM_THREADS = cluster_settings.OMP_NUM_THREADS
 modules = cluster_settings.modules
 parallel = cluster_settings.parallel
 
-nprocs = os.cpu_count()
+nproc = os.cpu_count()
 
 
 # ------- read user inputs -----------------------------------------------------
@@ -195,8 +195,8 @@ def generate_run_file(prefix, path, args, sq, lq, sr, lr, jobstring):
       f.write("mkdir -p " + outdir + "/%s\n" % (prefix))
       f.write("\n")
     
-      f.write(f"\n{parallel} -n {ppn} pw.x -in pw.in > pw.out\n")
-      f.write(f"\n{parallel} -n {ppn} ph.x -in ph_pre.in > ph_pre.out\n")
+      f.write(f"\n{parallel} -n {args.ppn} pw.x -in pw.in | tee pw.out\n")
+      f.write(f"\n{parallel} -n {args.ppn} ph.x -in ph_pre.in | tee ph_pre.out\n")
       f.write("\n")
       f.write("mkdir -p data\n") 
       f.write("mkdir -p data/dvscf\n") 
@@ -215,8 +215,8 @@ def generate_run_file(prefix, path, args, sq, lq, sr, lr, jobstring):
       f.write("mkdir -p %s/%s/\n" % (outdir, prefix))
       f.write("cp -r data/* %s/%s/\n\n" % (outdir, prefix))
       
-      f.write(f"\n{parallel} -n {ppn} ph.x -in ph_post.in > ph_post.out\n\n")
-      f.write(f"\n{parallel} -n 1 q2r.x -in q2r.in > q2r.out\n\n")
+      f.write(f"\n{parallel} -n {args.ppn} ph.x -in ph_post.in | tee ph_post.out\n\n")
+      f.write(f"\n{parallel} -n 1 q2r.x -in q2r.in | tee q2r.out\n\n")
       f.write("/usr/bin/rm -rf %s/%s\n" % (outdir, prefix))
       
 
@@ -246,7 +246,7 @@ def create_job_string(prev_string, sq, lq, sr, lr):
   string += "  mkdir -p %s/%s/%d_%d_%d_%d\n" % (outdir, prefix, sq, lq, sr, lr)
   string += "  cp -r data/* %s/%s/%d_%d_%d_%d/\n" % \
                                         (outdir, prefix, sq, lq, sr, lr)
-  string += f"  {parallel} -n {ppn} ph.x -in ph_{sq}_{lq}_{sr}_{lr}.in > ph_{sq}_{lq}_{sr}_{lr}.out\n\n")
+  string += f"  {parallel} -n {args.ppn} ph.x -in ph_{sq}_{lq}_{sr}_{lr}.in | tee ph_{sq}_{lq}_{sr}_{lr}.out\n\n")
   
   for iq in range(sq, lq+1):
     for ir in range(sr, lr+1): 
@@ -372,7 +372,7 @@ def generate_ph_file(prefix, path, args, sq, lq, sr, lr):
   with open(filename, "w") as f:
     f.write("title='%s'\n" % (args.title))  
     f.write(" &inputph\n")  
-    f.write("  tr2_ph=1.0d-14\n")
+    f.write("  tr2_ph=1.0d-22\n")
     f.write("  alpha_mix(1)=0.1\n")
     f.write("  ldisp=.true.\n")
     f.write("  search_sym=.false.\n")
